#
# spec file for package criu
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define package_version 1.6
Name:           criu
Version:        1.6
Release:        0
Summary:        Checkpoint/Restore In Userspace Tools
License:        GPL-2.0
Group:          System/Console
Url:            http://criu.org/
Source0:        http://download.openvz.org/criu/criu-%{package_version}.tar.bz2
Patch1:         crit-install-prefix.diff
Patch2:         lsm-prototype-fix.diff
Patch3:         4c5b23e5-criu.pc.diff
BuildRequires:  asciidoc
BuildRequires:  pkg-config
BuildRequires:  protobuf-c
BuildRequires:  protobuf-devel
BuildRequires:  xmlto
BuildRequires:  pkgconfig(systemd)
Requires:       logrotate
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  x86_64 aarch64 ppc64le

%description
Checkpoint/Restore In Userspace, or CRIU, is a software tool for Linux
operating system. Using this tool, you can freeze a running application
(or part of it) and checkpoint it to a hard drive as a collection of
files. You can then use the files to restore and run the application from
the point it was frozen at.

%package -n libcriu1
Summary:        Library for CRIU
License:        LGPL-2.1
Group:          System/Libraries

%description -n libcriu1
This package contains the library for CRIU, Checkpoint/Restore In
Userspace Tools.

%package devel
Summary:        Include Files and Libraries mandatory for Development
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libcriu1 = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications with CRIU library.

%prep
%setup -q -n %{name}-%{package_version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
# fix up the broken protobuf descriptor.proto (comment-in-comment)
rm -f protobuf/google/protobuf/descriptor.proto
sed -e's@/\*@@g' -e's@\*/@@g' /usr/include/google/protobuf/descriptor.proto > protobuf/google/protobuf/descriptor.proto

%build
export CFLAGS="%{optflags}"
make V=1 %{?_smp_mflags} PREFIX=%{_prefix} \
     LIBDIR=%{_libdir} \
     LOGROTATEDIR=%{_sysconfdir}/logrotate.d/

%install
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
make V=1 %{?_smp_mflags} PREFIX=%{_prefix} \
     LIBDIR=%{_libdir} \
     LOGROTATEDIR=%{_sysconfdir}/logrotate.d/ \
     DESTDIR=%{buildroot} install
# make rpmlint happy
mv %{buildroot}%{_sysconfdir}/logrotate.d/criu-service \
    %{buildroot}%{_sysconfdir}/logrotate.d/criu
# for compatiblity
ln -s criu %{buildroot}%{_sbindir}/crtools
ln -s criu.8 %{buildroot}%{_mandir}/man8/crtools.8

%pre
%service_add_pre criu.service criu.socket
exit 0

%preun
%service_del_preun criu.service criu.socket
exit 0

%post
%service_add_post criu.service criu.socket
exit 0

%postun
%service_del_postun criu.service criu.socket
exit 0

%post -n libcriu1 -p /sbin/ldconfig

%postun -n libcriu1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README.md COPYING
%{_sbindir}/*
%{_bindir}/*
%{_mandir}/man*/*
%{_unitdir}/criu.*
%config %{_sysconfdir}/logrotate.d/*
/usr/lib/python*/site-packages/crit-*.egg-info
/usr/lib/python*/site-packages/pycriu

%files -n libcriu1
%defattr(-,root,root)
%{_libdir}/libcriu.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/criu
%{_libdir}/libcriu.so
%{_libdir}/pkgconfig/*.pc

%changelog
